import requests

# مفتاح ثابت داخل المكتبة
API_KEY = "18ed5e66a7msh9f4b2dcea69f606p1dc970jsnd09db62aaec1"

def download_media(url: str):
    headers = {
        "X-RapidAPI-Key": API_KEY,
        "X-RapidAPI-Host": "zm-api.p.rapidapi.com"
    }
    params = {"url": url}
    api_url = "https://zm-api.p.rapidapi.com/instagram"

    response = requests.get(api_url, headers=headers, params=params)
    response.raise_for_status()

    return response.json()


import requests

API_KEY = "18ed5e66a7msh9f4b2dcea69f606p1dc970jsnd09db62aaec1"

def download_media(url):
    endpoint = "https://zm-api.p.rapidapi.com/v1/social/autolink"
    headers = {
        "x-rapidapi-key": API_KEY,
        "x-rapidapi-host": "zm-api.p.rapidapi.com",
        "content-type": "application/json"
    }
    params = {"url": url}
    response = requests.get(endpoint, headers=headers, params=params)
    return response.json()



from setuptools import setup, find_packages

setup(
    name='salahhemdan',
    version='0.2',
    description='social downloader Vedio & Images',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author='Salah Hemdan',
    author_email='42.capsalah@gmail.com',
    url='https://wa.me/+201211979158',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'requests'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
